
local strsplit = zo_strsplit;

QueryCampaignSelectionData();

CampaignCommands = {};

CampaignCommands.name = 'Campaign Commands';

commands = {};

createCommand = function ( commandName, name, ID )

	SLASH_COMMANDS[ commandName ] = function ( argtext )

		local args = { strsplit( ' ', argtext ) };

		group = false;

		if args[ 1 ] == 'group' then
			group = true;

			d( 'Queueing for ' .. name .. ' as a group.' );

		else
			d( 'Queueing for ' .. name .. '.' );
		end

		
		QueueForCampaign( ID, group );
	end

	commands[ commandName ] = name;
end

clearCommands = function ()

	for command in pairs( commands ) do

		SLASH_COMMANDS[ command ] = nil;
	end

	commands = {};
end

createCommands = function ()

	campaignCount = GetNumSelectionCampaigns();

	for i = 1, campaignCount do
		campaignID        = GetSelectionCampaignId( i );
		campaignName      = GetCampaignName( campaignID );
		campaignNameParts = {};

		for campaignNamePart in campaignName:gmatch( "%w+" ) do
			table.insert( campaignNameParts, campaignNamePart );

			command = '/' .. string.lower( table.concat( campaignNameParts, '' ) );

			createCommand( command, campaignName, campaignID );
		end
	end
end

listCommand = function ()

	d( 'Campaign Commands:' );

	for campaign, command in pairs( commands ) do
		d( '  ' .. campaign .. ' = ' .. command );
	end
end

currentCommand = function ()

	if IsInCampaign() then
		local currentCampaignID   = GetCurrentCampaignId();
		local currentCampaignName = GetCampaignName( campaignID );

		d( 'Current Campaign: ' .. currentCampaignName );

	else
		d( 'You are not in a Campaign.' );
	end
end

helpCommand = function ()

	d( '/campaign list' );
	d( '/campaign current' );
	d( '/campaign reload' );
end

reloadCommand = function ()

	clearCommands();
	createCommands();

	d( 'Campaign Commands Reloaded.' );
end

commandHandler = function ( argtext )

	local args = { strsplit( ' ', argtext ) };

	if args[ 1 ] == 'list' then
		listCommand();

	elseif args[ 1 ] == 'reload' then
		reloadCommand();

	elseif args[ 1 ] == 'current' then
		currentCommand();

	else
		helpCommand();
	end
end;

init = function ()

	SLASH_COMMANDS[ '/campaign list' ] = commandHandler;
	SLASH_COMMANDS[ '/campaign current' ] = commandHandler;
	SLASH_COMMANDS[ '/campaign reload' ] = commandHandler;
	SLASH_COMMANDS[ '/campaign' ] = commandHandler;

	createCommands();
end

EVENT_MANAGER:RegisterForEvent( 'Click Counter', EVENT_ADD_ON_LOADED, init );
